# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKVideoCorePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkRingBufferPython
else:
    import _itkRingBufferPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkOffsetPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkSymmetricSecondRankTensorPython

def itkRingBufferDO_New():
    return itkRingBufferDO.New()

class itkRingBufferDO(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferDO class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferDO_Pointer"""
        return _itkRingBufferPython.itkRingBufferDO___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferDO_Pointer"""
        return _itkRingBufferPython.itkRingBufferDO_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferDO_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferDO_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferDO_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferDO_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferDO_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferDO_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferDO_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkDataObject_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferDO_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkDataObject_Pointer

        """
        return _itkRingBufferPython.itkRingBufferDO_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferDO

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferDO

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferDO_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferDO

        Create a new object of the class itkRingBufferDO and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferDO.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferDO.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferDO.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferDO in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferDO_swigregister(itkRingBufferDO)

def itkRingBufferIF2_New():
    return itkRingBufferIF2.New()

class itkRingBufferIF2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferIF2_Pointer"""
        return _itkRingBufferPython.itkRingBufferIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferIF2_Pointer"""
        return _itkRingBufferPython.itkRingBufferIF2_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferIF2_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIF2_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF2_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferIF2_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferIF2_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF2_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIF2_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageF2_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF2_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageF2_Pointer

        """
        return _itkRingBufferPython.itkRingBufferIF2_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferIF2

        Create a new object of the class itkRingBufferIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferIF2 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferIF2_swigregister(itkRingBufferIF2)

def itkRingBufferIF3_New():
    return itkRingBufferIF3.New()

class itkRingBufferIF3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferIF3_Pointer"""
        return _itkRingBufferPython.itkRingBufferIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferIF3_Pointer"""
        return _itkRingBufferPython.itkRingBufferIF3_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferIF3_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIF3_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF3_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferIF3_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferIF3_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF3_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIF3_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageF3_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIF3_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageF3_Pointer

        """
        return _itkRingBufferPython.itkRingBufferIF3_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferIF3

        Create a new object of the class itkRingBufferIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferIF3 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferIF3_swigregister(itkRingBufferIF3)

def itkRingBufferISS2_New():
    return itkRingBufferISS2.New()

class itkRingBufferISS2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferISS2_Pointer"""
        return _itkRingBufferPython.itkRingBufferISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferISS2_Pointer"""
        return _itkRingBufferPython.itkRingBufferISS2_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferISS2_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferISS2_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS2_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferISS2_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferISS2_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS2_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferISS2_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageSS2_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS2_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageSS2_Pointer

        """
        return _itkRingBufferPython.itkRingBufferISS2_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferISS2

        Create a new object of the class itkRingBufferISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferISS2 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferISS2_swigregister(itkRingBufferISS2)

def itkRingBufferISS3_New():
    return itkRingBufferISS3.New()

class itkRingBufferISS3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferISS3_Pointer"""
        return _itkRingBufferPython.itkRingBufferISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferISS3_Pointer"""
        return _itkRingBufferPython.itkRingBufferISS3_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferISS3_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferISS3_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS3_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferISS3_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferISS3_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS3_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferISS3_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageSS3_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferISS3_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageSS3_Pointer

        """
        return _itkRingBufferPython.itkRingBufferISS3_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferISS3

        Create a new object of the class itkRingBufferISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferISS3 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferISS3_swigregister(itkRingBufferISS3)

def itkRingBufferIUC2_New():
    return itkRingBufferIUC2.New()

class itkRingBufferIUC2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferIUC2_Pointer"""
        return _itkRingBufferPython.itkRingBufferIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferIUC2_Pointer"""
        return _itkRingBufferPython.itkRingBufferIUC2_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferIUC2_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIUC2_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC2_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferIUC2_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferIUC2_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC2_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIUC2_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageUC2_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC2_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageUC2_Pointer

        """
        return _itkRingBufferPython.itkRingBufferIUC2_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferIUC2

        Create a new object of the class itkRingBufferIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferIUC2 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferIUC2_swigregister(itkRingBufferIUC2)

def itkRingBufferIUC3_New():
    return itkRingBufferIUC3.New()

class itkRingBufferIUC3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkRingBufferIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRingBufferIUC3_Pointer"""
        return _itkRingBufferPython.itkRingBufferIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRingBufferIUC3_Pointer"""
        return _itkRingBufferPython.itkRingBufferIUC3_Clone(self)

    def SetNumberOfBuffers(self, n):
        r"""
        SetNumberOfBuffers(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkRingBufferPython.itkRingBufferIUC3_SetNumberOfBuffers(self, n)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIUC3_GetNumberOfBuffers(self)

    def MoveHead(self, offset):
        r"""
        MoveHead(self, offset)

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC3_MoveHead(self, offset)

    def MoveHeadForward(self):
        r"""MoveHeadForward(self)"""
        return _itkRingBufferPython.itkRingBufferIUC3_MoveHeadForward(self)

    def MoveHeadBackward(self):
        r"""MoveHeadBackward(self)"""
        return _itkRingBufferPython.itkRingBufferIUC3_MoveHeadBackward(self)

    def BufferIsFull(self, offset):
        r"""
        BufferIsFull(self, offset) -> bool

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC3_BufferIsFull(self, offset)

    def GetHeadIndex(self):
        r"""GetHeadIndex(self) -> unsigned long"""
        return _itkRingBufferPython.itkRingBufferIUC3_GetHeadIndex(self)

    def GetBufferContents(self, offset):
        r"""
        GetBufferContents(self, offset) -> itkImageUC3_Pointer

        Parameters
        ----------
        offset: long

        """
        return _itkRingBufferPython.itkRingBufferIUC3_GetBufferContents(self, offset)

    def SetBufferContents(self, offset, element):
        r"""
        SetBufferContents(self, offset, element)

        Parameters
        ----------
        offset: long
        element: itkImageUC3_Pointer

        """
        return _itkRingBufferPython.itkRingBufferIUC3_SetBufferContents(self, offset, element)
    __swig_destroy__ = _itkRingBufferPython.delete_itkRingBufferIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRingBufferIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRingBufferPython.itkRingBufferIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRingBufferIUC3

        Create a new object of the class itkRingBufferIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRingBufferIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRingBufferIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRingBufferIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRingBufferIUC3 in _itkRingBufferPython:
_itkRingBufferPython.itkRingBufferIUC3_swigregister(itkRingBufferIUC3)

